The Search struct holds the current directory, the version to query, and optionally a package name.
It also includes a list of directories with package/dependency information.
Returns a colored string representing the package info and its dependencies.
The function takes a reference to a PackageAndDeps and a closure for coloring the version.
Returns a colored string representing the package info and its dependencies.
The function takes a reference to a PackageAndDeps and a closure for coloring the version.